@@ -9,12 +9,22 @@ BEGIN { @ISA = 'Module::Install::Base' }
 
 sub use_gloom {
     my $self = shift;
-    my $target = shift
+    my $module = shift
         or die "use_gloom requires the name of a target module";
+
+    my $gloom_path = $self->admin->find_in_inc('Gloom') or return;
+    open IN, $gloom_path or die "Can't open '$gloom_path' for input";
+    my $code = do { local $/; <IN> };
+    close IN;
+
+    $code =~ s/package Gloom;/package $module;/;
+
+    my $target = $module;
     $target =~ s/::/\//g;
     $target = "lib/$target.pm";
-    my $gloom_path = $self->admin->find_in_inc('Gloom') or return;
-    $self->admin->copy($gloom_path => $target);
+    open OUT, '>', $target or die "Can't open '$target' for output";
+    print OUT $code;
+    close OUT;
 }
 
 1;
